#
# spec file for package dvdisaster
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
Name:           dvdisaster
Version:        0.79.10
Release:        bp160.1.7
Summary:        Additional error protection for CD/DVD media
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Other
URL:            https://dvdisaster.jcea.es/
Source0:        https://dvdisaster.jcea.es/downloads/%{name}-%{version}.tar.bz2
Source1:        https://dvdisaster.jcea.es/downloads/%{name}-%{version}.tar.bz2.gpg
# PATCH-FIX-OPENSUSE correct desktop catagories.
Patch0:         dvdisaster-desktop-cat.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libpng16)
Requires:       dvdisaster-docs = %{version}

%description
%{name} provides a margin of safety against data loss on CD and DVD media
caused by scratches or aging. It creates error correction data,
which is used to recover unreadable sectors if the disc becomes damaged
at a later time.

%description -l cs
%{name} poskytuje dodatečnou ochranu proti ztrátě dat na médiích CD a DVD
způsobených poškrábáním nebo stárnutím. Vytváří data oprav chyb, která
jsou použita pro obnovu nečitelných sektorů, pokud se disk později
poškodí.

%description -l de
%{name} erzeugt einen Sicherheitspuffer gegen Datenverluste, die auf
CD- und DVD-Datenträgern durch Alterung oder Kratzer entstehen. Es erzeugt
Fehlerkorrekturdaten, um bei nachfolgenden Datenträger-Problemen unlesbare
Sektoren zu rekonstruieren.

%description -l it
%{name} offre un margine di sicurezza contro la perdita di dati dei supporti
CD e DVD causata dall'invecchiamento e dai graffi. Crea dei dati di correzione
degli errori che saranno poi utilizzati per recuperare i settori illeggibili
se il supporto dovesse danneggiarsi col tempo.

%package docs
Summary:        PDF Documentation for dvdisaster
Group:          Documentation/Other
BuildArch:      noarch

%description docs
Documentation package for using dvdisaster in PDF format.

%prep
%setup -q
%autopatch -p1
gmake -v | grep "GNU Make"

%build
#gcc10 is picky about global headers without extern, -fcommon fixes this for now.
export CFLAGS="%{optflags} -fcommon"
%configure --with-nls=yes \
           --docdir=%{_docdir} \
           --docsubdir=%{name} \
           --localedir=%{_datadir}/locale \
           --buildroot=%{buildroot}
make --trace

# Parallel make breaks translations sometimes.
#%%{?_smp_mflags}
%install
rm -f dvdisaster.lang
%make_install
mkdir -p %{buildroot}%{_datadir}/applications
cp -v contrib/%{name}.desktop %{buildroot}%{_datadir}/applications/
%suse_update_desktop_file %{name}
%find_lang %{name}
pushd %{buildroot}%{_docdir}/%{name}
rm -f `ls |grep -v manual.pdf
popd`
rm -f %{buildroot}%{_bindir}/dvdisaster-uninstall.sh
%fdupes -s %{buildroot}/%{_prefix}

%files -f dvdisaster.lang
%{_bindir}/%{name}
# NOTE: adding COPYING to the doc directory as well as license
#is not a mistake it's for the license display in the help menu
%doc README CHANGELOG CREDITS.de CREDITS.en TODO COPYING
%license COPYING
%{_mandir}/de/man1/%{name}.1%{ext_man}
%{_mandir}/man1/%{name}.1%{ext_man}
%{_datadir}/applications/%{name}.desktop

%files docs
%{_docdir}/%{name}/manual.pdf

%changelog
* Sun Jun 25 2023 Dave Plater <davejplater@gmail.com>
- Update to version 0.79.10
- Add dvdisaster-desktop-cat.patch to correct desktop catagory.
- Remove obsolete patches:
  dvdisaster-findmake.patch, 02-encryption.patch, 03-dvdrom.patch,
  05-help-dialog.patch, 08-fix-gnu-make-detection.patch,
  10-use-non-size-specific-icon-and-add-keywords-to-desktop-file.patch,
  11-no-cruft.patch, 12-fix-spelling-of-up-to.patch,
  13-fix-missing-language-field-in-po-files.patch,
  14-make-builds-reproducible.patch, 15-show-new-pkg-tracker.patch,
  16-remove-auto-build-of-doco-from-install-rule.patch,
  17-fix-all-but-deprecated-api-warnings.patch,
  18-update-copyright-in-about-dialog.patch,
  19-show-text-files-with-abs-path.patch,
  20-display-changelog-credits-and-todo.patch,
  22-fix-hurd-i386-ftbfs.patch, 23-add-bdrom-support.patch,
  24-show-gpl3-license.patch, 25-fix-man-pages.patch'
  26-fix-display-of-manual.pdf.patch,
  27-allow-opening-in-browser-again.patch,
  28-pdftex-reproducibility.patch, 29-fix-more-typos.patch,
  30-hurd-kfreebsd-ftbfs.patch,
  31-improve-hurd-and-kfreebsd-support.patch,
  32-display-compilation-commands.patch, 33-honour-LDFLAGS.patch,
  34-gcc8-format-security.patch, 35-archived-homepage.patch,
  36-fix-parallelism.patch, 37-suggest-dvdisaster-doc.patch,
  dvdisaster-no-tex.patch, dvdisaster-g_strdup_printf.patch.
- Upstream changes:
  Many fixes see:
  /usr/share/doc/packages/dvdisaster/CHANGELOG
* Sun Jan 23 2022 Dave Plater <davejplater@gmail.com>
- Add more debian patches:
  12-fix-spelling-of-up-to.patch Added
  15-show-new-pkg-tracker.patch Added
  16-remove-auto-build-of-doco-from-install-rule.patch Added
  19-show-text-files-with-abs-path.patch Added
  20-display-changelog-credits-and-todo.patch Added
  26-fix-display-of-manual.pdf.patch Added
  31-improve-hurd-and-kfreebsd-support.patch Added
  33-honour-LDFLAGS.patch Added
  35-archived-homepage.patch Added
  36-fix-parallelism.patch Added
- Fix boo#1195036 with dvdisaster-g_strdup_printf.patch
* Fri Jun  5 2020 Dave Plater <davejplater@gmail.com>
- Fix Factory build with gcc10 and add Debian patches:
  29-fix-more-typos.patch, 23-add-bdrom-support.patch,
  34-gcc8-format-security.patch, 02-encryption.patch,
  17-fix-all-but-deprecated-api-warnings.patch,
  10-use-non-size-specific-icon-and-add-keywords-to-desktop-file.patch
  25-fix-man-pages.patch, 14-make-builds-reproducible.patch,
  11-no-cruft.patch, 18-update-copyright-in-about-dialog.patch,
  30-hurd-kfreebsd-ftbfs.patch, 22-fix-hurd-i386-ftbfs.patch,
  03-dvdrom.patch, 37-suggest-dvdisaster-doc.patch,
  13-fix-missing-language-field-in-po-files.patch,
  32-display-compilation-commands.patch,
  28-pdftex-reproducibility.patch, 05-help-dialog.patch,
  27-allow-opening-in-browser-again.patch and
  24-show-gpl3-license.patch
- Created dvdisaster-no-tex.patch to pevent building of existing
  pdf manual.
* Thu Jan 11 2018 avindra@opensuse.org
-  Update to version 0.79.6
  * Verify/Test option will now output dvdisaster version numbers
    always in x.yy.zz format, as the old scheme using x.yy
    (devel|pre|rc|pl)-zz is no longer used.
  * The "medium info" tool will now correctly show the blank
    capacity (was previously always shown as zero)
  * added support for BDXL-TL (triple layer, 100GB)
  * Sector CRC sums and the image MD5 sum are collected during
    reading the medium and can be re-used by the ecc data creation
    process. Speeds up ecc generation and enables RS03 image
    checksums when generating ecc data was preceeded by a read.
- cleanup spec file with spec-cleaner
- rebase dvdisaster-findmake.patch
- add upstream urls to sources
- add pgp signature
* Sun Oct 23 2016 davejplater@gmail.com
- Created initial package, version 0.79.5
